from django.conf import settings
from django.contrib.auth import get_user_model
from django.core import mail
from django.db.models.signals import post_save
from django.dispatch import receiver

User = get_user_model()


@receiver(post_save, sender=User)
def send_confirmation_email(sender, instance, created, raw, **kwargs):
    if settings.CONFIRM_EMAIL_ENABLED and created and not raw:
        mail.send_mail(
            settings.CONFIRM_EMAIL_SUBJECT, settings.CONFIRM_EMAIL_BODY,
            settings.CONFIRM_EMAIL_SENDER, [instance.email],
            fail_silently=False,
        )


from django.conf import settings
from django.core.exceptions import ValidationError
from rest_framework import status
from rest_framework.response import Response
from .base import BaseValidator

import requests


class FacebookValidator(BaseValidator):
    def __init__(self):
        self.valid = False
        if settings.FACEBOOK_APP_ID and settings.FACEBOOK_CLIENT_SECRET:
            self.valid = True

    def validate(self, token):
        if not self.valid:
            raise ValidationError('Facebook Login Not Supported')

        if settings.TESTING:
            response = Response(status=status.HTTP_200_OK)
        else:
            response = requests.get(settings.FACEBOOK_VALIDATION_URL % (token, settings.FACEBOOK_APP_ID, settings.FACEBOOK_CLIENT_SECRET))

        return response.status_code is status.HTTP_200_OK
